@@ -75,6 +75,11 @@ def DJANGO_VAR_ENCLOSING_TAG(m):
     text = "{{ %s }}" % text.strip()
     return enclose_tag(tag, text)
 
+@syntax('(.*?) \|\|')
+def EMPTY_TAG(m):
+    tag = m.groups()[0]
+    return enclose_tag(tag, "")
+
 @syntax('(.*?) \|% (.*)')
 def DJANGO_TAG_ENCLOSING_TAG(m):
     tag, text = m.groups()
@@ -103,6 +108,7 @@ LINE_METHODS = [
         OUTER_CLOSING_TAG,
         DJANGO_TAG_ENCLOSING_TAG,
         DJANGO_VAR_ENCLOSING_TAG,
+        EMPTY_TAG,
         TEXT_ENCLOSING_TAG,
         SELF_CLOSING_TAG,
         RAW_TEXT,
